@@ -1,5 +1,5 @@
 #define DOCTEST_CONFIG_IMPLEMENTATION_IN_DLL
-#include "doctest.h"
+#include <doctest/doctest.h>
 
 DOCTEST_MAKE_STD_HEADERS_CLEAN_FROM_WARNINGS_ON_WALL_BEGIN
 #include <cstdio>
